| Title: | An R-Shiny Application for Creating Visual Abstracts |
|---|---|
| Description: | An R-Shiny application to create visual abstracts for original research. A variety of user defined options and formatting are included. |
| Authors: | Matthew Kumar <[email protected]> |
| Maintainer: | Matthew Kumar <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-20 06:50:57 UTC |
| Source: | https://github.com/cran/abstractr |
abstractr() loads interactive user interface built using R shiny.
abstractr()abstractr()
Start abstractr
The interactive application makes creating visual abstracts fast and intuitive. While the application has certain design elements fixed, namely layout, a vignette is included to guide customizations from scratch.
## Not run: library(shiny) abstractr() ## End(Not run)## Not run: library(shiny) abstractr() ## End(Not run)