Welcome to ClientVPS Mirrors

Help for package abstractr
Type: Package
Title: An R-Shiny Application for Creating Visual Abstracts
Version: 0.1.0
Author: Matthew Kumar <mattkumar@gmail.com>
Maintainer: Matthew Kumar <mattkumar@gmail.com>
Description: An R-Shiny application to create visual abstracts for original research. A variety of user defined options and formatting are included.
URL: https://matt-kumar.shinyapps.io/portfolio
Imports: shiny (≥ 1.2.0), ggplot2 (≥ 3.0.0), gridExtra (≥ 2.3.0), colourpicker, shinythemes, emojifont, rintrojs
License: GPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.0.1
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2019-01-14 22:41:00 UTC; Kumar
Repository: CRAN
Date/Publication: 2019-01-20 17:20:03 UTC

Launch abstractr GUI

Description

abstractr() loads interactive user interface built using R shiny.

Usage

abstractr()

Details

Start abstractr

The interactive application makes creating visual abstracts fast and intuitive. While the application has certain design elements fixed, namely layout, a vignette is included to guide customizations from scratch.

Examples

## Not run: 
library(shiny)
abstractr()

## End(Not run)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.